The Diagram feature of NetDoc has been inspired by [Netbox Topology Views Plugin](https://github.com/mattieserver/netbox-topology-views "Netbox Topology Views Plugin") by [mattieserver](https://github.com/mattieserver "mattieserver"). After few attempts, I decided to fork and integrate it within NetDoc.

As in [Netbox Topology Views Plugin](https://github.com/mattieserver/netbox-topology-views "Netbox Topology Views Plugin"), [vis.js](https://visjs.org/ "vis.js") is used to draw diagrams.
